/*******************************************************************************
 *
 * @file	boot.c
 * @brief	This is vector and interrupt program with C.
 *
 * @par		Copyright:
 *			Copyright (C) SEIKO EPSON CORPORATION 2013-2018. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 10/04/2013	1.00
 *				- First revision.
 *			- 03/27/2014	1.10
 *				- Change source code.
 *			- 06/25/2014	1.20
 *				- Change source code.
 *			- 05/18/2015	1.30
 *				- Change source code.
 *			- 10/29/2018	1.40
 *				- Change source code.
 *
 ******************************************************************************/



extern unsigned short __START_stack[];
void _start( void );
void _start1(void);
void _init_device( void);

#if __GNUC__ < 4

#include <string.h>
#include <stdio.h>
#include <libstdio.h>

/* --- definition --- */

/* --- function declaration --- */

static void clearBss(void);
static void loadLmaToVmaData(void);
static void end(void);

// Non Maskable Interrupt Handler
void intAddrErr(void)			__attribute__ ((interrupt_handler));
void intReserved(void)		__attribute__ ((interrupt_handler));

/* --- external declaration --- */

extern int main(void);
extern void emu_copro_process(void);
extern unsigned long __START_bss;
extern unsigned long __END_bss;
extern unsigned long __START_data;
extern unsigned long __START_data_lma;
extern unsigned long __END_data;

/* special definitions for vector table  */
typedef void func(void);
#ifdef __POINTER16
#define VECTOR(vec)  ( vec ),0
#else
#define VECTOR(vec)  ( vec )
#endif

/** vector table */
func *const vector[] = {			// No	Base+	Name

	/* ----- Non-Maskable Interrupts ----- */
	VECTOR( _start ),				// 0	00		Reset
	VECTOR( intAddrErr ),			// 1	04		Address misaligned
	VECTOR( intReserved ),			// 2	08		NMI
	VECTOR( emu_copro_process ),	// 3	0C		Co-processor emulation

	VECTOR( intReserved ),			// 4	10		SVD interrupt
	VECTOR( intReserved ),			// 5	14		PORT interrupt
	VECTOR( intReserved ),			// 6	18		PWG2 interrupt
	VECTOR( intReserved ),			// 7	1C		CLG interrupt
	VECTOR( intReserved ),			// 8	20		RTC interrupt
	VECTOR( intReserved ),			// 9	24		T16 ch.0 interrupt
	VECTOR( intReserved ),			// 10	28		UART Ch.0 interrupt
	VECTOR( intReserved ),			// 11	2C		T16 ch.1 interrupt
	VECTOR( intReserved ),			// 12	30		SPI Ch.0 interrupt
	VECTOR( intReserved ),			// 13	34		I2C interrupt
	VECTOR( intReserved ),			// 14	38		T16B ch.0 interrupt
	VECTOR( intReserved ),			// 15	3C		T16B ch.1 interrupt
	VECTOR( intReserved ),			// 16	40		T16B ch.2 interrupt
	VECTOR( intReserved ),			// 17	44		UART Ch.1 interrupt
	VECTOR( intReserved ),			// 18	48		T16 ch.2 interrupt
	VECTOR( intReserved ),			// 19	4C		SPI Ch.1 interrupt
	VECTOR( intReserved ),			// 20	50		SNDA interrupt
	VECTOR( intReserved ),			// 21	54		REMC interrupt
	VECTOR( intReserved ),			// 22	58		LCD24A interrupt
	VECTOR( intReserved ),			// 23	5C		RFC ch.0 interrupt
	VECTOR( intReserved ),			// 24	60		RFC ch.1 interrupt
	VECTOR( intReserved ),			// 25	64		T16 ch.3 interrupt
	VECTOR( intReserved ),			// 26	68		ADC12A interrupt
	VECTOR( intReserved ),			// 27	6C		reserved
	VECTOR( intReserved ),			// 28	70		reserved
	VECTOR( intReserved ),			// 29	74		reserved
	VECTOR( intReserved ),			// 30	78		reserved
	VECTOR( intReserved )			// 31	7C		reserved

};
#endif /* __GNUC__ */

/****************************************************************************
 * _start function.
 *
 * @brief	 Start module.
 *			 If DEBUGCUT_FROM_RESET is declared, it sets to debug prohibited.
 ***************************************************************************/
void _start(void)
{
#ifdef DEBUGCUT_FROM_RESET
	DebugInterfaceDisable();
#endif // DEBUGCUT_FROM_RESET

	asm volatile("xld.a %%sp, %0"::"i"(__START_stack));
	asm volatile("xjpa %0"::"i"(_start1));
}

/****************************************************************************
 * _init_device function.
 *
 * @brief	If DEBUGCUT_AFTER_A_WHILE is declared, wait at least 50 cycles,
 *		 	and set it to debug prohibited.
 ***************************************************************************/
void _init_device(void)
{
#ifdef DEBUGCUT_AFTER_A_WHILE
	volatile int i;

	// Enabling debug function immediately after reset only.
	// Wait 50 or more instructions from the head of the reset handler routine.
	for( i = 0 ; i < 50 ; i++ ) {
		asm( "nop ");
	}

	DebugInterfaceDisable();
#endif // DEBUGCUT_AFTER_A_WHILE

	//setFlashcAccessCycle( FLASHCWAIT_RDWAIT_1 );

	return;
}

#if __GNUC__ < 4

/****************************************************************************
 * boot function.
 *
 * @brief	First, it resets the Stack Pointer, clear the bss area,
 * 			and copy LMA to VMA.
 *			Next, it calls "main" function and calls "end" function.
 ***************************************************************************/
void _start1(void)
{
	int status;


	/// Initialize module.
	_init_device();

	/// Initialize section.
	clearBss();						/// - Clear the bss area.
	loadLmaToVmaData();				/// - Copy LMA data to VMA data(".data" section).

	asm ( "ei" );					/// Interrupt enable.

	status = main(); 				/// Call main.

	end(); 							/// Call end.

}

/* ----- static ----- */

/****************************************************************************
 * clearBss function.
 *
 * @brief	Clear ".bss" Section.
 ***************************************************************************/
static void clearBss(void)
{
	unsigned char	*addr;
	unsigned long	size;
	unsigned long	i;

	addr	= (unsigned char *)&__START_bss;
	size	= (unsigned long)&__END_bss - (unsigned long)&__START_bss;

	/// Clear ".bss" section.
	for(i = 0 ; i < size ; i++){
		*addr++ = 0x00;
	}

	return;
}

/****************************************************************************
 * loadLmaToVma function.
 *
 * @brief	This function copys LMA data to VMA data(".data" section).
 ***************************************************************************/
static void loadLmaToVmaData(void)
{
	unsigned char		*src;
	unsigned char		*dst;
	unsigned long		size;
	unsigned long		i;

	/// Load ".data" section.
	src		= (unsigned char *)&__START_data_lma;
	dst		= (unsigned char *)&__START_data;
	size	= (unsigned long)&__END_data - (unsigned long)&__START_data;

	for(i = 0 ; i < size ; i++){
		*dst++ = *src++;
	}

}


/****************************************************************************
 * end function.
 *
 * @brief	This function has only infinite loop.
 ***************************************************************************/
static void end(void)
{
	/// Infinite loop.
	while ( 1 ){
		;
	}
}

/* ----- Non Maskable Interrupt Handler ----- */

/****************************************************************************
 * intAddrErr function.
 *
 * @brief	Interrupt handler for "Address misaligned".
 ***************************************************************************/
void intAddrErr(void)
{
	/// Infinite loop.
	while ( 1 ){
		;
	}
}


/****************************************************************************
 * intReserved function.
 *
 * @brief	Interrupt handler for "Reserved".
 ***************************************************************************/
void intReserved(void)
{
	/// Infinite loop.
	while ( 1 ){
		;
	}
}
#endif /* __GNUC__ */


