/************************************************************************//**
 *
 * @file	adc12a_reg.h
 *
 * @brief	Definition of the 12-bit A/D Converter(ADC12A) Register.
 *
 * @par		Copyright:
 *			Copyright(C) SEIKO EPSON CORPORATION 2016-2016. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 01 Sep. 2016    1.00
 *				- First revision.
 *
 ******************************************************************************/

#ifndef ADC12A_REG_H__
#define ADC12A_REG_H__

#ifdef __cplusplus
extern "C" {
#endif

/// ADC12A Ch.0 Control Register
typedef union ADC12_NCTL_REG_TAG {
    unsigned short  reg;
    struct ADC12_NCTL_REG_BIT_TAG {
        /**
         * This bit enables the ADC12A operations.
         * .MODEN
         *  This bit enables the ADC12A operations.
         *    1 (R/W): Enable ADC12A operations (The operating clock is supplied.)
         *    0 (R/W): Disable ADC12A operations (The operating clock is stopped.)
         */
        unsigned short      MODEN       : 1;
        /**
         * This bit starts A/D conversion or enables to accept triggers.
         * .ADST
         *  This bit starts A/D conversion or enables to accept triggers.
         *    1 (R/W): Start sampling and conversion (software trigger)/Enable trigger acceptance (external trigger, 16-bit timer underflow trigger)
         *    0 (R/W): Terminate conversion
         */
        unsigned short      ADST        : 1;
        unsigned short      reserved_1  : 8;    ///< Reserved.
        /**
         * This bit indicates whether the ADC12A is executing A/D conversion or not.
         * .BSYSTAT
         *  This bit indicates whether the ADC12A is executing A/D conversion or not.
         *    1 (R/W): A/D converting
         *    0 (R/W): Idle
         */
        unsigned short      BSYSTAT     : 1;
        unsigned short      reserved_2  : 1;    ///< Reserved.
        /**
         * These bits indicate the analog input pin number m being A/D converted.
         * .ADSTAT[2:0]
         *  These bits indicate the analog input pin number m being A/D converted.
         * +-------------+-------------------+
         * | ADSTAT[2:0] | Analog input pin  |
         * +-------------+-------------------+
         * |     0x7     |     ADIN07        |
         * +-------------+-------------------+
         * |     0x6     |     ADIN06        |
         * +-------------+-------------------+
         * |     0x5     |     ADIN05        |
         * +-------------+-------------------+
         * |     0x4     |     ADIN04        |
         * +-------------+-------------------+
         * |     0x3     |     ADIN03        |
         * +-------------+-------------------+
         * |     0x2     |     ADIN02        |
         * +-------------+-------------------+
         * |     0x1     |     ADIN01        |
         * +-------------+-------------------+
         * |     0x0     |     ADIN00        |
         * +-------------+-------------------+
         */
        unsigned short      ADSTAT      : 3;
        unsigned short      reserved_3  : 1;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} ADC12_NCTL_REG;

/// ADC12A Ch.0 Trigger/Analog Input Select Register
typedef union ADC12_NTRG_REG_TAG {
    unsigned short  reg;
    struct ADC12_NTRG_REG_BIT_TAG {
        /**
         * These bits set the analog input signal sampling time.
         * .SMPCLK[2:0]
         *  These bits set the analog input signal sampling time.
         * +-------------+-------------------+
         * | SMPCLK[2:0] | Sampling time     |
         * +-------------+-------------------+
         * |     0x7     |   11 cycle        |
         * +-------------+-------------------+
         * |     0x6     |   10 cycle        |
         * +-------------+-------------------+
         * |     0x5     |    9 cycle        |
         * +-------------+-------------------+
         * |     0x4     |    8 cycle        |
         * +-------------+-------------------+
         * |     0x3     |    7 cycle        |
         * +-------------+-------------------+
         * |     0x2     |    6 cycle        |
         * +-------------+-------------------+
         * |     0x1     |    5 cycle        |
         * +-------------+-------------------+
         * |     0x0     |    4 cycle        |
         * +-------------+-------------------+
         */
        unsigned short      SMPCLK      : 3;
        unsigned short      reserved_1  : 1;    ///< Reserved.
        /**
         * These bits select a trigger source to start A/D conversion.
         * .CNVTRG[1:0]
         *  These bits select a trigger source to start A/D conversion.
         * +-------------+--------------------------------------+
         * | CNVTRG[1:0] | Trigger source                       |
         * +-------------+--------------------------------------+
         * |     0x3     | #ADTRGn pin(external trigger)        |
         * +-------------+--------------------------------------+
         * |     0x2     | Reserved                             |
         * +-------------+--------------------------------------+
         * |     0x1     | 16-bit timer Ch.k underflow          |
         * +-------------+--------------------------------------+
         * |     0x0     | ADC12_0CTL.ADST bit(software trigger)|
         * +-------------+--------------------------------------+
         */
        unsigned short      CNVTRG      : 2;
        /**
         * This bit sets the A/D conversion mode.
         * .CNVMD
         *  This bit sets the A/D conversion mode.
         *    1 (R/W): Continuous conversion mode
         *    0 (R/W): One-time conversion mode
         */
        unsigned short      CNVMD       : 1;
        /**
         * This bit selects the data alignment when the conversion results are loaded into the A/D conversion result registers.
         * .STMD
         *  This bit selects the data alignment when the conversion results are loaded into the A/D conversion result registers.
         *    1 (R/W): Left justify
         *    0 (R/W): Right justify
         */
        unsigned short      STMD        : 1;
        /**
         * These bits set the analog input pin to be A/D converted first.
         * .STAAIN[2:0]
         *  These bits set the analog input pin to be A/D converted first.
         * +-------------+-------------------+
         * | STAAIN[2:0] | Analog input pin  |
         * +-------------+-------------------+
         * |     0x7     |     ADIN07        |
         * +-------------+-------------------+
         * |     0x6     |     ADIN06        |
         * +-------------+-------------------+
         * |     0x5     |     ADIN05        |
         * +-------------+-------------------+
         * |     0x4     |     ADIN04        |
         * +-------------+-------------------+
         * |     0x3     |     ADIN03        |
         * +-------------+-------------------+
         * |     0x2     |     ADIN02        |
         * +-------------+-------------------+
         * |     0x1     |     ADIN01        |
         * +-------------+-------------------+
         * |     0x0     |     ADIN00        |
         * +-------------+-------------------+
         */
        unsigned short      STAAIN      : 3;
        /**
         * These bits set the analog input pin to be A/D converted last.
         * .ENDAIN[2:0]
         *  These bits set the analog input pin to be A/D converted last.
         * +-------------+-------------------+
         * | ENDAIN[2:0] | Analog input pin  |
         * +-------------+-------------------+
         * |     0x7     |     ADIN07        |
         * +-------------+-------------------+
         * |     0x6     |     ADIN06        |
         * +-------------+-------------------+
         * |     0x5     |     ADIN05        |
         * +-------------+-------------------+
         * |     0x4     |     ADIN04        |
         * +-------------+-------------------+
         * |     0x3     |     ADIN03        |
         * +-------------+-------------------+
         * |     0x2     |     ADIN02        |
         * +-------------+-------------------+
         * |     0x1     |     ADIN01        |
         * +-------------+-------------------+
         * |     0x0     |     ADIN00        |
         * +-------------+-------------------+
         */
        unsigned short      ENDAIN      : 3;
        unsigned short      reserved_2  : 2;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} ADC12_NTRG_REG;

/// ADC12A Ch.0 Configuration Register
typedef union ADC12_NCFG_REG_TAG {
    unsigned short  reg;
    struct ADC12_NCFG_REG_BIT_TAG {
#if  defined(C17_MCUSEL_M20) || defined(C17_MCUSEL_M21) || defined(C17_MCUSEL_M22) || defined(C17_MCUSEL_M23) || defined(C17_MCUSEL_M24) || defined(C17_MCUSEL_M25)
        /**
         * These bits set the A/D converter operating voltage range.
         * .VRANGE[1:0]
         *  These bits set the A/D converter operating voltage range.
         * +-------------+--------------------------------------+
         * | VRANGE[1:0] | A/D converter operating voltage range|
         * +-------------+--------------------------------------+
         * |     0x3     |           1.8 to 5.5V                |
         * +-------------+--------------------------------------+
         * |     0x2     |           3.6 to 5.5V                |
         * +-------------+--------------------------------------+
         * |     0x1     |           4.8 to 5.5V                |
         * +-------------+--------------------------------------+
         * |     0x0     |          Conversion disabel          |
         * +-------------+--------------------------------------+
         */
#else
        /**
         * These bits set the A/D converter operating voltage range.
         * .VRANGE[1:0]
         *  These bits set the A/D converter operating voltage range.
         * +-------------+--------------------------------------+
         * | VRANGE[1:0] | A/D converter operating voltage range|
         * +-------------+--------------------------------------+
         * |     0x3     |           1.8 to 3.6V                |
         * +-------------+--------------------------------------+
         * |     0x2     |             Reserved                 |
         * +-------------+--------------------------------------+
         * |     0x1     |             Reserved                 |
         * +-------------+--------------------------------------+
         * |     0x0     |          Conversion disabel          |
         * +-------------+--------------------------------------+
         */
#endif
        unsigned short      VRANGE      : 2;
        unsigned short      reserved_1  :14;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} ADC12_NCFG_REG;

/// ADC12A Ch.0 Interrupt Flag Register
typedef union ADC12_NINTF_REG_TAG {
    unsigned short  reg;
    struct ADC12_NINTF_REG_BIT_TAG {
        /**
         * This bit indicate Analog input signal 0 A/D conversion completion interrupt cause occurrence status.
         * .AD0CIF
         *  This bit indicate Analog input signal 0 A/D conversion completion interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      AD0CIF      : 1;
        /**
         * This bit indicate Analog input signal 1 A/D conversion completion interrupt cause occurrence status.
         * .AD1CIF
         *  This bit indicate Analog input signal 1 A/D conversion completion interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      AD1CIF      : 1;
        /**
         * This bit indicate Analog input signal 2 A/D conversion completion interrupt cause occurrence status.
         * .AD2CIF
         *  This bit indicate Analog input signal 2 A/D conversion completion interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      AD2CIF      : 1;
        /**
         * This bit indicate Analog input signal 3 A/D conversion completion interrupt cause occurrence status.
         * .AD3CIF
         *  This bit indicate Analog input signal 3 A/D conversion completion interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      AD3CIF      : 1;
        /**
         * This bit indicate Analog input signal 4 A/D conversion completion interrupt cause occurrence status.
         * .AD4CIF
         *  This bit indicate Analog input signal 4 A/D conversion completion interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      AD4CIF      : 1;
        /**
         * This bit indicate Analog input signal 5 A/D conversion completion interrupt cause occurrence status.
         * .AD5CIF
         *  This bit indicate Analog input signal 5 A/D conversion completion interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      AD5CIF      : 1;
        /**
         * This bit indicate Analog input signal 6 A/D conversion completion interrupt cause occurrence status.
         * .AD6CIF
         *  This bit indicate Analog input signal 6 A/D conversion completion interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      AD6CIF      : 1;
        /**
         * This bit indicate Analog input signal 7 A/D conversion completion interrupt cause occurrence status.
         * .AD7CIF
         *  This bit indicate Analog input signal 7 A/D conversion completion interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      AD7CIF      : 1;
        /**
         * This bit indicate Analog input signal 0 A/D conversion result overwrite error interrupt cause occurrence status.
         * .AD0OVIF
         *  This bit indicate Analog input signal 0 A/D conversion result overwrite error interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      AD0OVIF     : 1;
        /**
         * This bit indicate Analog input signal 1 A/D conversion result overwrite error interrupt cause occurrence status.
         * .AD1OVIF
         *  This bit indicate Analog input signal 1 A/D conversion result overwrite error interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      AD1OVIF     : 1;
        /**
         * This bit indicate Analog input signal 2 A/D conversion result overwrite error interrupt cause occurrence status.
         * .AD2OVIF
         *  This bit indicate Analog input signal 2 A/D conversion result overwrite error interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      AD2OVIF     : 1;
        /**
         * This bit indicate Analog input signal 3 A/D conversion result overwrite error interrupt cause occurrence status.
         * .AD3OVIF
         *  This bit indicate Analog input signal 3 A/D conversion result overwrite error interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      AD3OVIF     : 1;
        /**
         * This bit indicate Analog input signal 4 A/D conversion result overwrite error interrupt cause occurrence status.
         * .AD4OVIF
         *  This bit indicate Analog input signal 4 A/D conversion result overwrite error interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      AD4OVIF     : 1;
        /**
         * This bit indicate Analog input signal 5 A/D conversion result overwrite error interrupt cause occurrence status.
         * .AD5OVIF
         *  This bit indicate Analog input signal 5 A/D conversion result overwrite error interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      AD5OVIF     : 1;
        /**
         * This bit indicate Analog input signal 6 A/D conversion result overwrite error interrupt cause occurrence status.
         * .AD6OVIF
         *  This bit indicate Analog input signal 6 A/D conversion result overwrite error interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      AD6OVIF     : 1;
        /**
         * This bit indicate Analog input signal 7 A/D conversion result overwrite error interrupt cause occurrence status.
         * .AD7OVIF
         *  This bit indicate Analog input signal 7 A/D conversion result overwrite error interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      AD7OVIF     : 1;
    } bit;
    unsigned char   byte_reg[2];
} ADC12_NINTF_REG;

/// ADC12A Ch.0 Interrupt Enable Register
typedef union ADC12_NINTE_REG_TAG {
    unsigned short  reg;
    struct ADC12_NINTE_REG_BIT_TAG {
        /**
         * This bit enable Analog input signal 0 A/D conversion completion interrupt.
         * .AD0CIE
         *  This bit enable Analog input signal 0 A/D conversion completion interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      AD0CIE      : 1;
        /**
         * This bit enable Analog input signal 1 A/D conversion completion interrupt.
         * .AD1CIE
         *  This bit enable Analog input signal 1 A/D conversion completion interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      AD1CIE      : 1;
        /**
         * This bit enable Analog input signal 2 A/D conversion completion interrupt.
         * .AD2CIE
         *  This bit enable Analog input signal 2 A/D conversion completion interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      AD2CIE      : 1;
        /**
         * This bit enable Analog input signal 3 A/D conversion completion interrupt.
         * .AD3CIE
         *  This bit enable Analog input signal 3 A/D conversion completion interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      AD3CIE      : 1;
        /**
         * This bit enable Analog input signal 4 A/D conversion completion interrupt.
         * .AD4CIE
         *  This bit enable Analog input signal 4 A/D conversion completion interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      AD4CIE      : 1;
        /**
         * This bit enable Analog input signal 5 A/D conversion completion interrupt.
         * .AD5CIE
         *  This bit enable Analog input signal 5 A/D conversion completion interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      AD5CIE      : 1;
        /**
         * This bit enable Analog input signal 6 A/D conversion completion interrupt.
         * .AD6CIE
         *  This bit enable Analog input signal 6 A/D conversion completion interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      AD6CIE      : 1;
        /**
         * This bit enable Analog input signal 7 A/D conversion completion interrupt.
         * .AD7CIE
         *  This bit enable Analog input signal 7 A/D conversion completion interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      AD7CIE      : 1;
        /**
         * This bit enable Analog input signal 0 A/D conversion result overwrite error interrupt.
         * .AD0OVIE
         *  This bit enable Analog input signal 0 A/D conversion result overwrite error interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      AD0OVIE     : 1;
        /**
         * This bit enable Analog input signal 1 A/D conversion result overwrite error interrupt.
         * .AD1OVIE
         *  This bit enable Analog input signal 1 A/D conversion result overwrite error interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      AD1OVIE     : 1;
        /**
         * This bit enable Analog input signal 2 A/D conversion result overwrite error interrupt.
         * .AD2OVIE
         *  This bit enable Analog input signal 2 A/D conversion result overwrite error interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      AD2OVIE     : 1;
        /**
         * This bit enable Analog input signal 3 A/D conversion result overwrite error interrupt.
         * .AD3OVIE
         *  This bit enable Analog input signal 3 A/D conversion result overwrite error interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      AD3OVIE     : 1;
        /**
         * This bit enable Analog input signal 4 A/D conversion result overwrite error interrupt.
         * .AD4OVIE
         *  This bit enable Analog input signal 4 A/D conversion result overwrite error interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      AD4OVIE     : 1;
        /**
         * This bit enable Analog input signal 5 A/D conversion result overwrite error interrupt.
         * .AD5OVIE
         *  This bit enable Analog input signal 5 A/D conversion result overwrite error interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      AD5OVIE     : 1;
        /**
         * This bit enable Analog input signal 6 A/D conversion result overwrite error interrupt.
         * .AD6OVIE
         *  This bit enable Analog input signal 6 A/D conversion result overwrite error interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      AD6OVIE     : 1;
        /**
         * This bit enable Analog input signal 7 A/D conversion result overwrite error interrupt.
         * .AD7OVIE
         *  This bit enable Analog input signal 7 A/D conversion result overwrite error interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      AD7OVIE     : 1;
    } bit;
    unsigned char   byte_reg[2];
} ADC12_NINTE_REG;

/// ADC12A Ch.0 Result Register 0
typedef union ADC12_0ADND_REG_TAG {
    unsigned short  reg;
    struct ADC12_0ADND_REG_BIT_TAG {
        /// These bits are the A/D conversion results of the analog input signal 0.
        unsigned short      AD0D        :16;
    } bit;
    unsigned char   byte_reg[2];
} ADC12_0ADND_REG;

/// ADC12A Ch.0 Result Register 1
typedef union ADC12_NAD1D_REG_TAG {
    unsigned short  reg;
    struct ADC12_NAD1D_REG_BIT_TAG {
        /// These bits are the A/D conversion results of the analog input signal 1.
        unsigned short      AD1D        :16;
    } bit;
    unsigned char   byte_reg[2];
} ADC12_NAD1D_REG;

/// ADC12A Ch.0 Result Register 2
typedef union ADC12_NAD2D_REG_TAG {
    unsigned short  reg;
    struct ADC12_NAD2D_REG_BIT_TAG {
        /// These bits are the A/D conversion results of the analog input signal 2.
        unsigned short      AD2D        :16;
    } bit;
    unsigned char   byte_reg[2];
} ADC12_NAD2D_REG;

/// ADC12A Ch.0 Result Register 3
typedef union ADC12_NAD3D_REG_TAG {
    unsigned short  reg;
    struct ADC12_NAD3D_REG_BIT_TAG {
        /// These bits are the A/D conversion results of the analog input signal 3.
        unsigned short      AD3D        :16;
    } bit;
    unsigned char   byte_reg[2];
} ADC12_NAD3D_REG;

/// ADC12A Ch.0 Result Register 4
typedef union ADC12_NAD4D_REG_TAG {
    unsigned short  reg;
    struct ADC12_NAD4D_REG_BIT_TAG {
        /// These bits are the A/D conversion results of the analog input signal 4.
        unsigned short      AD4D        :16;
    } bit;
    unsigned char   byte_reg[2];
} ADC12_NAD4D_REG;

/// ADC12A Ch.0 Result Register 5
typedef union ADC12_NAD5D_REG_TAG {
    unsigned short  reg;
    struct ADC12_NAD5D_REG_BIT_TAG {
        /// These bits are the A/D conversion results of the analog input signal 5.
        unsigned short      AD5D        :16;
    } bit;
    unsigned char   byte_reg[2];
} ADC12_NAD5D_REG;

/// ADC12A Ch.0 Result Register 6
typedef union ADC12_NAD6D_REG_TAG {
    unsigned short  reg;
    struct ADC12_NAD6D_REG_BIT_TAG {
        /// These bits are the A/D conversion results of the analog input signal 6.
        unsigned short      AD6D        :16;
    } bit;
    unsigned char   byte_reg[2];
} ADC12_NAD6D_REG;

/// ADC12A Ch.0 Result Register 7
typedef union ADC12_NAD7D_REG_TAG {
    unsigned short  reg;
    struct ADC12_NAD7D_REG_BIT_TAG {
        /// These bits are the A/D conversion results of the analog input signal 7.
        unsigned short      AD7D        :16;
    } bit;
    unsigned char   byte_reg[2];
} ADC12_NAD7D_REG;

#ifdef __cplusplus
}
#endif

#endif // ADC12A_REG_H__
