/************************************************************************//**
 *
 * @file	spia_reg.h
 *
 * @brief	Definition of the Synchronous Serial Interface(SPIA) Register.
 *
 * @par		Copyright:
 *			Copyright(C) SEIKO EPSON CORPORATION 2016-2016. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 01 Sep. 2016    1.00
 *				- First revision.
 *
 ******************************************************************************/


#ifndef SPIA_REG_H__
#define SPIA_REG_H__

#ifdef __cplusplus
extern "C" {
#endif

/// ----- SPIA ----

/// SPIA Ch.N Mode Register
typedef union SPINMOD_REG_TAG {
    unsigned short  reg;
    struct SPINMOD_REG_BIT_TAG {
        /**
         * This bit sets the SPIA operating mode (master mode or slave mode).
         * .MST
         *  This bit sets the SPIA operating mode (master mode or slave mode).
         *    1 (R/W): Master mode
         *    0 (R/W): Slave mode
         */
        unsigned short      MST         : 1;
        /**
         * This bit set the SPI clock polarity.
         * .CPOL
         *  This bit set the SPI clock polarity.
         */
        unsigned short      CPOL        : 1;
        /**
         * This bit set the SPI clock phase polarity.
         * .CPHA
         *  This bit set the SPI clock phase polarity.
         */
        unsigned short      CPHA        : 1;
        /**
         * This bit configures the data format (input/output permutation).
         * .LSBFST
         *  This bit configures the data format (input/output permutation).
         *    1 (R/W): LSB first
         *    0 (R/W): MSB first
         */
        unsigned short      LSBFST      : 1;
        /**
         * This bit selects SPICLKn in master mode. This setting is ineffective in slave mode.
         * .NOCLKDIV
         *  This bit selects SPICLKn in master mode. This setting is ineffective in slave mode.
         *    1 (R/W): SPICLKn frequency = CLK_SPIAn frequency ( = 16-bit timer operating clock frequency)
         *    0 (R/W): SPICLKn frequency = 16-bit timer output frequency / 2
         */
        unsigned short      NOCLKDIV    : 1;
        /**
         * This bit enables pull-up/down of the input pins.
         * .PUEN
         *  This bit enables pull-up/down of the input pins.
         *    1 (R/W): Enable pull-up/down
         *    0 (R/W): Disable pull-up/down
         */
        unsigned short      PUEN        : 1;
        unsigned short      reserved_1  : 2;    ///< Reserved.
        /**
         * These bits set the bit length of transfer data.
         * .CHLN[3:0]
         *  These bits set the bit length of transfer data.
         * +----------+--------------------+
         * |CHLN[3:0] | Data bit length    |
         * +----------+--------------------+
         * |   0xf    |      16 bits       |
         * +----------+--------------------+
         * |   0xe    |      15 bits       |
         * +----------+--------------------+
         * |   0xd    |      14 bits       |
         * +----------+--------------------+
         * |   0xc    |      13 bits       |
         * +----------+--------------------+
         * |   0xb    |      12 bits       |
         * +----------+--------------------+
         * |   0xa    |      11 bits       |
         * +----------+--------------------+
         * |   0x9    |      10 bits       |
         * +----------+--------------------+
         * |   0x8    |       9 bits       |
         * +----------+--------------------+
         * |   0x7    |       8 bits       |
         * +----------+--------------------+
         * |   0x6    |       7 bits       |
         * +----------+--------------------+
         * |   0x5    |       6 bits       |
         * +----------+--------------------+
         * |   0x4    |       5 bits       |
         * +----------+--------------------+
         * |   0x3    |       4 bits       |
         * +----------+--------------------+
         * |   0x2    |       3 bits       |
         * +----------+--------------------+
         * |   0x1    |       2 bits       |
         * +----------+--------------------+
         * |   0x0    | Setting prohibited |
         * +----------+--------------------+
         */
        unsigned short      CHLN        : 4;
        unsigned short      reserved_2  : 4;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} SPINMOD_REG;

/// SPIA Ch.N Control Register
typedef union SPINCTL_REG_TAG {
    unsigned short  reg;
    struct SPINCTL_REG_BIT_TAG {
        /**
         * This bit enables the SPIA operations.
         * .MODEN
         *  This bit enables the SPIA operations.
         *    1 (R/W): Enable SPIA operations (In master mode, the operating clock is supplied.)
         *    0 (R/W): Disable SPIA operations (In master mode, the operating clock is stopped.)
         */
        unsigned short      MODEN       : 1;
        /**
         * This bit issues software reset to SPIA.
         * .SFTRST
         *  This bit issues software reset to SPIA.
         *   1 (W): Issue software reset
         *   0 (W): Ineffective
         *   1 (R): Software reset is executing.
         *   0 (R): Software reset has finished. (During normal operation)
         */
        unsigned short      SFTRST      : 1;
        unsigned short      reserved_1  :14;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} SPINCTL_REG;

/// SPIA Ch.N Transmit Data Register
typedef union SPINTXD_REG_TAG {
    unsigned short  reg;
    struct SPINTXD_REG_BIT_TAG {
        /**
         * Data can be written to the transmit data buffer through these bits.
         * .TXD[15:0]
         *  Data can be written to the transmit data buffer through these bits.
         */
        unsigned short      TXD         :16;
    } bit;
    unsigned char   byte_reg[2];
} SPINTXD_REG;

/// SPIA Ch.N Receive Data Register
typedef union SPINRXD_REG_TAG {
    unsigned short  reg;
    struct SPINRXD_REG_BIT_TAG {
        /**
         * The receive data buffer can be read through these bits.
         * .RXD[15:0]
         *  The receive data buffer can be read through these bits.
         */
        unsigned short      RXD         :16;
    } bit;
    unsigned char   byte_reg[2];
} SPINRXD_REG;

/// SPIA Ch.N Interrupt Flag Register
typedef union SPININTF_REG_TAG {
    unsigned short  reg;
    struct SPININTF_REG_BIT_TAG {
        /**
         * This bit indicate Transmit buffer empty interrupt cause occurrence status.
         * .TBEIF
         *  This bit indicate Transmit buffer empty interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    0 (W): Ineffective
         */
        unsigned short      TBEIF       : 1;
        /**
         * This bit indicate Receive buffer full interrupt cause occurrence status.
         * .RBFIF
         *  This bit indicate Receive buffer full interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    0 (W): Ineffective
         */
        unsigned short      RBFIF       : 1;
        /**
         * This bit indicate End-of-transmission interrupt cause occurrence status.
         * .TENDIF
         *  This bit indicate End-of-transmission interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      TENDIF      : 1;
        /**
         * This bit indicate Overrun error interrupt cause occurrence status.
         * .OEIF
         *  This bit indicate Overrun error interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      OEIF        : 1;
        unsigned short      reserved_1  : 3;    ///< Reserved.
        /**
         * This bit indicates the SPIA operating status.
         * .BSY
         *  This bit indicates the SPIA operating status.
         *    1 (R): Transmit/receive busy (master mode), #SPISSn = Low level (slave mode)
         *    0 (R): Idle
         */
        unsigned short      BSY         : 1;
        unsigned short      reserved_2  : 8;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} SPININTF_REG;

/// SPIA Ch.N Interrupt Enable Register
typedef union SPININTE_REG_TAG {
    unsigned short  reg;
    struct SPININTE_REG_BIT_TAG {
        /**
         * This bit enable Transmit buffer empty interrupt.
         * .TBEIE
         *  This bit enable Transmit buffer empty interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      TBEIE       : 1;
        /**
         * This bit enable Receive buffer full interrupt.
         * .RBFIE
         *  This bit enable Receive buffer full interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      RBFIE       : 1;
        /**
         * This bit enable End-of-transmission interrupt.
         * .TENDIE
         *  This bit enable End-of-transmission interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      TENDIE      : 1;
        /**
         * This bit enable Overrun error interrupt.
         * .OEIE
         *  This bit enable Overrun error interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      OEIE        : 1;
        unsigned short      reserved_1  :12;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} SPININTE_REG;

#ifdef __cplusplus
}
#endif

#endif // SPIA_REG_H__
