/************************************************************************//**
 *
 * @file	t16_reg.h
 *
 * @brief	Definition of the 16-bit Timer(T16) Register.
 *
 * @par		Copyright:
 *			Copyright(C) SEIKO EPSON CORPORATION 2016-2016. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 01 Sep. 2016    1.00
 *				- First revision.
 *
 ******************************************************************************/

#ifndef T16_REG_H__
#define T16_REG_H__

#ifdef __cplusplus
extern "C" {
#endif

/// T16 Ch.N Clock Control Register
typedef union T16_NCLK_REG_TAG {
    unsigned short  reg;
    struct T16_NCLK_REG_BIT_TAG {
        /**
         * These bits select the clock source of T16 Ch.n.
         * .CLKSRC[1:0]
         *  These bits select the clock source of T16 Ch.n.
         * .CLKDIV[3:0]
         *  These bits select the division ratio of the T16 Ch.n operating clock (counter clock). 
         * +-------------+-----------------------------------+
         * |             |           CLKSRC[1:0]             |
         * |             +--------+--------+--------+--------+
         * | CLKDIV[3:0] |  0x0   |   0x1  |  0x2   |  0x3   |
         * |             +--------+--------+--------+--------+
         * |             |  IOSC  |  OSC1  |  OSC3  | EXOSC/ |
         * |             |        |        |        | EXCLm  |
         * +-------------+--------+--------+--------+--------+
         * |     0xf     |1/32,768|1/1     |1/32,768|1/1     |
         * +-------------+--------+        +--------+        +
         * |     0xe     |1/16,384|        |1/16,384|        |
         * +-------------+--------+        +--------+        +
         * |     0xd     |1/8,192 |        |1/8,192 |        |
         * +-------------+--------+        +--------+        +
         * |     0xc     |1/4,096 |        |1/4,096 |        |
         * +-------------+--------+        +--------+        +
         * |     0xb     |1/2,048 |        |1/2,048 |        |
         * +-------------+--------+        +--------+        +
         * |     0xa     |1/1,024 |        |1/1,024 |        |
         * +-------------+--------+        +--------+        +
         * |     0x9     |1/512   |        |1/512   |        |
         * +-------------+--------+--------+--------+        +
         * |     0x8     |1/256   |1/256   |1/256   |        |
         * +-------------+--------+--------+--------+        +
         * |     0x7     |1/128   |1/128   |1/128   |        |
         * +-------------+--------+--------+--------+        +
         * |     0x6     |1/64    |1/64    |1/64    |        |
         * +-------------+--------+--------+--------+        +
         * |     0x5     |1/32    |1/32    |1/32    |        |
         * +-------------+--------+--------+--------+        +
         * |     0x4     |1/16    |1/16    |1/16    |        |
         * +-------------+--------+--------+--------+        +
         * |     0x3     |1/8     |1/8     |1/8     |        |
         * +-------------+--------+--------+--------+        +
         * |     0x2     |1/4     |1/4     |1/4     |        |
         * +-------------+--------+--------+--------+        +
         * |     0x1     |1/2     |1/2     |1/2     |        |
         * +-------------+--------+--------+--------+        +
         * |     0x0     |1/1     |1/1     |1/1     |        |
         * +-------------+--------+--------+--------+--------+
         */
        unsigned short      CLKSRC      : 2;
        unsigned short      reserved_1  : 2;    ///< Reserved.
        /**
         * These bits select the division ratio of the T16 Ch.n operating clock (counter clock). 
         * .CLKSRC[1:0]
         *  These bits select the clock source of T16 Ch.n.
         * .CLKDIV[3:0]
         *  These bits select the division ratio of the T16 Ch.n operating clock (counter clock). 
         * +-------------+-----------------------------------+
         * |             |           CLKSRC[1:0]             |
         * |             +--------+--------+--------+--------+
         * | CLKDIV[3:0] |  0x0   |   0x1  |  0x2   |  0x3   |
         * |             +--------+--------+--------+--------+
         * |             |  IOSC  |  OSC1  |  OSC3  | EXOSC/ |
         * |             |        |        |        | EXCLm  |
         * +-------------+--------+--------+--------+--------+
         * |     0xf     |1/32,768|1/1     |1/32,768|1/1     |
         * +-------------+--------+        +--------+        +
         * |     0xe     |1/16,384|        |1/16,384|        |
         * +-------------+--------+        +--------+        +
         * |     0xd     |1/8,192 |        |1/8,192 |        |
         * +-------------+--------+        +--------+        +
         * |     0xc     |1/4,096 |        |1/4,096 |        |
         * +-------------+--------+        +--------+        +
         * |     0xb     |1/2,048 |        |1/2,048 |        |
         * +-------------+--------+        +--------+        +
         * |     0xa     |1/1,024 |        |1/1,024 |        |
         * +-------------+--------+        +--------+        +
         * |     0x9     |1/512   |        |1/512   |        |
         * +-------------+--------+--------+--------+        +
         * |     0x8     |1/256   |1/256   |1/256   |        |
         * +-------------+--------+--------+--------+        +
         * |     0x7     |1/128   |1/128   |1/128   |        |
         * +-------------+--------+--------+--------+        +
         * |     0x6     |1/64    |1/64    |1/64    |        |
         * +-------------+--------+--------+--------+        +
         * |     0x5     |1/32    |1/32    |1/32    |        |
         * +-------------+--------+--------+--------+        +
         * |     0x4     |1/16    |1/16    |1/16    |        |
         * +-------------+--------+--------+--------+        +
         * |     0x3     |1/8     |1/8     |1/8     |        |
         * +-------------+--------+--------+--------+        +
         * |     0x2     |1/4     |1/4     |1/4     |        |
         * +-------------+--------+--------+--------+        +
         * |     0x1     |1/2     |1/2     |1/2     |        |
         * +-------------+--------+--------+--------+        +
         * |     0x0     |1/1     |1/1     |1/1     |        |
         * +-------------+--------+--------+--------+--------+
         */
        unsigned short      CLKDIV      : 4;
        /**
         * This bit sets whether the T16 Ch.N operating clock is supplied in DEBUG mode or not.
         * .DBRUN
         *  This bit sets whether the T16 Ch.N operating clock is supplied in DEBUG mode or not.
         *    1 (R/W): Clock supplied in DEBUG mode
         *    0 (R/W): No clock supplied in DEBUG mode
         */
        unsigned short      DBRUN       : 1;
        unsigned short      reserved_2  : 7;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} T16_NCLK_REG;

/// T16 Ch.N Mode Register
typedef union T16_NMOD_REG_TAG {
    unsigned short  reg;
    struct T16_NMOD_REG_BIT_TAG {
        /**
         * T16 Ch.N Mode Register
         * .TRMD
         *  This bit selects the T16 operation mode.
         *    1 (R/W): One-shot mode
         *    0 (R/W): Repeat mode
         */
        unsigned short      TRMD        : 1;
        unsigned short      reserved_1  :15;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} T16_NMOD_REG;

/// T16 Ch.N Control Register
typedef union T16_NCTL_REG_TAG {
    unsigned short  reg;
    struct T16_NCTL_REG_BIT_TAG {
        /**
         * This bit enables the T16 operations(Ch.N).
         * .MODEN
         *  This bit enables the T16 Ch.N operations.
         *    1 (R/W): Enable (Start supplying operating clock)
         *    0 (R/W): Disable (Stop supplying operating clock)
         */
        unsigned short      MODEN       : 1;
        /**
         * This bit presets the reload data stored in the T16_nTR register to the counter.
         * .PRESET
         *  This bit presets the reload data stored in the T16_nTR register to the counter.
         *    1 (W): Preset
         *    0 (W): Ineffective
         *    1 (R): Presetting in progress
         *    0 (R): Presetting finished or normal operation
         */
        unsigned short      PRESET      : 1;
        unsigned short      reserved_1  : 6;    ///< Reserved.
        /**
         * This bit starts/stops the timer(Ch.N).
         * .PRUN
         *  This bit starts/stops the timer.
         *    1 (W): Start timer
         *    0 (W): Stop timer
         *    1 (R): Timer is running
         *    0 (R): Timer is idle
         */
        unsigned short      PRUN        : 1;
        unsigned short      reserved_2  : 7;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} T16_NCTL_REG;

/// T16 Ch.N Reload Data Register
typedef union T16_NTR_REG_TAG {
    unsigned short  reg;
    struct T16_NTR_REG_BIT_TAG {
        /**
         * T16 Ch.N Reload Data Register
         * .TR[15:0]
         *  These bits are used to set the initial value to be preset to the counter.
         *  The value set to this register will be preset to the counter when 1 is written to the T16_nCTL.PRESET
         *  bit or when the counter underflows.
         */
        unsigned short      TR          :16;
    } bit;
    unsigned char   byte_reg[2];
} T16_NTR_REG;

/// T16 Ch.N Counter Data Register
typedef union T16_NTC_REG_TAG {
    unsigned short  reg;
    struct T16_NTC_REG_BIT_TAG {
        /**
         * T16 Ch.N Counter Data Register
         * .TC[15:0]
         *  The current counter value can be read out from these bits.
         */
        unsigned short      TC          :16;
    } bit;
    unsigned char   byte_reg[2];
} T16_NTC_REG;

/// T16 Ch.N Interrupt Flag Register
typedef union T16_NINTF_REG_TAG {
    unsigned short  reg;
    struct T16_NINTF_REG_BIT_TAG {
        /**
         * This bit indicates the T16 Ch.n underflow interrupt cause occurrence status.
         * .UFIF
         *  This bit indicates the T16 Ch.n underflow interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      UFIF        : 1;
        unsigned short      reserved_1  :15;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} T16_NINTF_REG;

/// T16 Ch.N Interrupt Enable Register
typedef union T16_NINTE_REG_TAG {
    unsigned short  reg;
    struct T16_NINTE_REG_BIT_TAG {
        /**
         * This bit enables T16 Ch.n underflow interrupts.
         * .UFIE
         *  This bit enables T16 Ch.n underflow interrupts.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      UFIE        : 1;
        unsigned short      reserved_1  :15;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} T16_NINTE_REG;

#ifdef __cplusplus
}
#endif

#endif // T16_REG_H__
