/****************************************************************************
 *
 * @file	OscControl.c
 * @brief	OSC Control file.
 *
 * @par		Copyright:
 *			Copyright (C) SEIKO EPSON CORPORATION 2015-2021. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 01/22/2018    1.00
 *				- First revision.
 *			- 08/05/2019    1.10
 *              - speeding up.
 *			- 12/23/2019    1.20
 *				- modify bus access cycles revision.
 *			- 08/06/2021    1.30
 *				- modify OscClockSourceInitialize,OscClockSourceFinalize.
 *
 ***************************************************************************/
#include "c17m24_reg.h"

static unsigned short saveOSC_CTL;
static unsigned short saveCLG_OSC3;
static unsigned short saveOSC_CLK_SRC;
static unsigned short saveFLASHWAIT;

static unsigned short saveT16_0CLK;
static unsigned short saveT16_0MOD;
static unsigned short saveT16_0CTL;
static unsigned short saveT16_0TR;
static unsigned short saveT16_0INTE;


/************************************************************************//**
 * @brief   Start OSC3.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
static void Osc3ClockSet(void)
{
	/// Clear interrupt flag(CLGINTF.OSC3STAIF).
	CLGINTF					= 0x0004;

	//OSC3 enable
	CLGOSC_OSC3EN = 0x01;

	while ( CLGINTF_OSC3STAIF == 0 ) {
		asm("nop");		// wait ...
	}
	//Clock=OSC3
	CLGSCLK_CLKSRC = 0x02;
}


/************************************************************************//**
 * @brief   Set the operating clock(OSC3).
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void OscClockSourceInitialize(void)
{
	// save reg
	saveOSC_CTL = CLGOSC;
	saveCLG_OSC3 = CLGOSC3;
	saveOSC_CLK_SRC = CLGSCLK;
	saveFLASHWAIT = FLASHCWAIT;

	saveT16_0CLK = T16_0CLK;
	saveT16_0MOD = T16_0MOD;
	saveT16_0CTL = T16_0CTL;
	saveT16_0TR = T16_0TR;
	saveT16_0INTE = T16_0INTE;


	/// Disable write-protect.
	MSCPROT = 0x96;

	//Flash Read Cycle = 3 cycle  18.9 MHz (max.)
	FLASHCWAIT = 0x02;

	/// It doesn't do at all when having already started.
	if(CLGSCLK_CLKSRC == 0x02)
	{
		CLGOSC_IOSCEN = 0x01;	//IOSC enable
		CLGSCLK_CLKSRC = 0x00;	//Clock=IOSC
	}

	//Clock Division=1/1
	CLGSCLK_CLKDIV = 0x00;
	/// Stop OSC3.
	CLGOSC_OSC3EN = 0x00;
	//OSC3=Internal
	CLGOSC3_OSC3MD = 0x00;
	//OSC3=16MHz
	CLGOSC3_OSC3FQ = 0x01;

	Osc3ClockSet();

	if((saveOSC_CTL & 0x0001) != 0x0001)
	{
		CLGOSC_IOSCEN = 0x00;	//IOSC disable
	}

	//T16 setting
	T16_0CLK = 0x0002;			// T16 Clock=OSC3 16MHz
	T16_0CTL = 1;				// T16 enable
	T16_0MOD = 1;     			// One shot mode
	T16_0INTE = 0;				// Interrupt disable
}

/************************************************************************//**
 * @brief   Restore the operating clock setting.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void OscClockSourceFinalize(void)
{
	MSCPROT = 0x96;

	if(CLGOSC3 != saveCLG_OSC3)
	{
		//IOSC enable
		CLGOSC_IOSCEN = 0x01;
		//Clock=IOSC
		CLGSCLK_CLKSRC = 0x00;

		/// Stop OSC3.
		CLGOSC_OSC3EN = 0x00;

		CLGOSC3 = saveCLG_OSC3;

		Osc3ClockSet();

	}
    CLGSCLK = saveOSC_CLK_SRC;
    CLGOSC = saveOSC_CTL;

    T16_0CLK = saveT16_0CLK;
    T16_0MOD = saveT16_0MOD;
    T16_0CTL = saveT16_0CTL;
    T16_0TR = saveT16_0TR;
    T16_0INTE = saveT16_0INTE;

    FLASHCWAIT = saveFLASHWAIT;

	MSCPROT = 0x00;
}
